@@ -82,7 +82,9 @@ class ADOClient:
         :returns: True if we have access, False otherwise
         """
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories?api-version=1.0"
+        request_url = (
+            self.http_client.api_endpoint(is_default_collection=False) + "/projects?api-version=6.0"
+        )
 
         try:
             response = self.http_client.get(request_url)
@@ -98,6 +100,7 @@ class ADOClient:
         *,
         source_branch: str,
         target_branch: str,
+        project_id: str,
         repository_id: str,
         title: Optional[str] = None,
         description: Optional[str] = None,
@@ -107,6 +110,7 @@ class ADOClient:
 
         :param str source_branch: The source branch of the pull request
         :param str target_branch: The target branch of the pull request
+        :param project_id: The ID of the project
         :param str repository_id: The ID for the repository
         :param Optional[str] title: The title of the pull request
         :param Optional[str] description: The description of the pull request
@@ -118,7 +122,7 @@ class ADOClient:
         """
         self.log.debug("Creating pull request")
 
-        request_url = f"{self.http_client.api_endpoint()}/git/repositories/{repository_id}"
+        request_url = f"{self.http_client.api_endpoint(project_id=project_id)}/git/repositories/{repository_id}"
         request_url += "/pullRequests?api-version=5.1"
 
         body: Dict[str, Any] = {
@@ -138,22 +142,28 @@ class ADOClient:
         response = self.http_client.post(request_url, json_data=body)
         return self.http_client.decode_response(response)
 
-    def pull_request(self, pull_request_id: int, repository_id: str) -> ADOPullRequestClient:
+    def pull_request(
+        self, pull_request_id: int, project_id: str, repository_id: str
+    ) -> ADOPullRequestClient:
         """Get an ADOPullRequestClient for the PR identifier.
 
         :param pull_request_id: The ID of the pull request to create the client for
+        :param project_id: The ID of the project the PR is in
         :param repository_id: The ID of repository the pull request is on
 
         :returns: A new ADOPullRequest client for the pull request specified
         """
-        return ADOPullRequestClient(self.http_client, self.log, pull_request_id, repository_id)
+        return ADOPullRequestClient(
+            self.http_client, self.log, pull_request_id, project_id, repository_id
+        )
 
     def list_all_pull_requests(
-        self, *, branch_name: Optional[str] = None, repository_id: str,
+        self, *, branch_name: Optional[str] = None, project_id: str, repository_id: str,
     ) -> ADOResponse:
         """Get the pull requests for a branch from ADO.
 
         :param Optional[str] branch_name: The name of the branch to fetch the pull requests for.
+        :param project_id: The ID of the project
         :param str repository_id: The ID for the repository
 
         :returns: The ADO Response with the pull request data
@@ -166,8 +176,10 @@ class ADOClient:
 
         while True:
 
-            request_url = f"{self.http_client.api_endpoint()}/git/repositories"
-            request_url += f"/{repository_id}/pullRequests?"
+            request_url = (
+                self.http_client.api_endpoint(project_id=project_id)
+                + f"/git/repositories/{repository_id}/pullRequests?"
+            )
 
             request_url += f"$top=100&$skip={offset}"
 
@@ -196,7 +208,6 @@ class ADOClient:
         url_fragment: str,
         parameters: Dict[str, Any],
         is_default_collection: bool = True,
-        is_project: bool = True,
         is_internal: bool = False,
         subdomain: Optional[str] = None,
         project_id: Optional[str] = None,
@@ -215,10 +226,9 @@ class ADOClient:
         :param str url_fragment: The part of the URL that comes after `_apis/`
         :param Dict[str,Any] parameters: The URL parameters to append
         :param bool is_default_collection: Whether this URL should start with the path "/DefaultCollection"
-        :param bool is_project: Whether this URL should scope down to include `project_id`
         :param bool is_internal: Whether this URL should use internal API endpoint "/_api"
         :param Optional[str] subdomain: A subdomain that should be used (if any)
-        :param Optional[str] project_id: The project ID. This must be set if `is_project` is set
+        :param Optional[str] project_id: The project ID (if required)
 
         :returns: The raw response
         """
@@ -226,7 +236,6 @@ class ADOClient:
         encoded_parameters = urllib.parse.urlencode(parameters)
         request_url = self.http_client.api_endpoint(
             is_default_collection=is_default_collection,
-            is_project=is_project,
             is_internal=is_internal,
             subdomain=subdomain,
             project_id=project_id,
